@@ -139,20 +139,23 @@ def copy_examples_directory(dest: Path, console) -> Result[bool, str]:
         return Failure(f"Failed to copy examples: {e}")
 
 
-# Agent configuration for multi-agent support (DX-11)
+# Agent configuration for multi-agent support (DX-11, DX-17)
 AGENT_CONFIGS = {
     "claude": {
         "file": "CLAUDE.md",
+        "template": "CLAUDE.md.template",
         "reference": '> **Protocol:** Follow [INVAR.md](./INVAR.md) for the Invar development methodology.\n',
         "check_pattern": "INVAR.md",
     },
     "cursor": {
         "file": ".cursorrules",
+        "template": "cursorrules.template",
         "reference": "Follow the Invar Protocol in INVAR.md.\n\n",
         "check_pattern": "INVAR.md",
     },
     "aider": {
         "file": ".aider.conf.yml",
+        "template": "aider.conf.yml.template",
         "reference": "# Follow the Invar Protocol in INVAR.md\nread:\n  - INVAR.md\n",
         "check_pattern": "INVAR.md",
     },
@@ -217,6 +220,163 @@ def add_invar_reference(path: Path, agent: str, console) -> Result[bool, str]:
         return Failure(f"Failed to update {config['file']}: {e}")
 
 
+def create_agent_config(path: Path, agent: str, console) -> Result[bool, str]:
+    """
+    Create agent config from template (DX-17).
+
+    Creates full template file for agents that don't have an existing config.
+    """
+    if agent not in AGENT_CONFIGS:
+        return Failure(f"Unknown agent: {agent}")
+
+    config = AGENT_CONFIGS[agent]
+    config_path = path / config["file"]
+
+    if config_path.exists():
+        return Success(False)  # Already exists
+
+    # Use template if available
+    template_name = config.get("template")
+    if template_name:
+        result = copy_template(template_name, path, config["file"])
+        if isinstance(result, Success) and result.unwrap():
+            console.print(f"[green]Created[/green] {config['file']} (Invar workflow enforcement)")
+            return Success(True)
+        elif isinstance(result, Failure):
+            return result
+
+    return Success(False)
+
+
+def configure_mcp_server(path: Path, console) -> Result[list[str], str]:
+    """
+    Configure MCP server for AI agents (DX-16).
+
+    Creates:
+    - .invar/mcp-server.json (universal config)
+    - .invar/mcp-setup.md (manual setup instructions)
+    - Updates .claude/settings.json if .claude/ exists
+
+    Returns list of configured agents.
+    """
+    import json
+
+    configured: list[str] = []
+    invar_dir = path / ".invar"
+
+    # Ensure .invar exists
+    if not invar_dir.exists():
+        invar_dir.mkdir()
+
+    # MCP config using current Python (the one that has invar installed)
+    import sys
+
+    mcp_config = {
+        "name": "invar",
+        "command": sys.executable,
+        "args": ["-m", "invar.mcp"],
+    }
+
+    # 1. Create .mcp.json at project root (Claude Code standard)
+    mcp_json_path = path / ".mcp.json"
+    if not mcp_json_path.exists():
+        mcp_json_content = {
+            "mcpServers": {
+                "invar": {
+                    "command": mcp_config["command"],
+                    "args": mcp_config["args"],
+                }
+            }
+        }
+        mcp_json_path.write_text(json.dumps(mcp_json_content, indent=2))
+        console.print("[green]Created[/green] .mcp.json (MCP server config)")
+        configured.append("Claude Code")
+    else:
+        # Check if invar is already configured
+        try:
+            existing = json.loads(mcp_json_path.read_text())
+            if "mcpServers" in existing and "invar" in existing.get("mcpServers", {}):
+                console.print("[dim]Skipped[/dim] .mcp.json (invar already configured)")
+            else:
+                # Add invar to existing config
+                if "mcpServers" not in existing:
+                    existing["mcpServers"] = {}
+                existing["mcpServers"]["invar"] = {
+                    "command": mcp_config["command"],
+                    "args": mcp_config["args"],
+                }
+                mcp_json_path.write_text(json.dumps(existing, indent=2))
+                console.print("[green]Updated[/green] .mcp.json (added invar)")
+            configured.append("Claude Code")
+        except (OSError, json.JSONDecodeError):
+            console.print("[yellow]Warning[/yellow] .mcp.json exists but couldn't update")
+
+    # 2. Create setup instructions (for reference)
+    mcp_setup = invar_dir / "mcp-setup.md"
+    if not mcp_setup.exists():
+        mcp_setup.write_text(_MCP_SETUP_TEMPLATE)
+        console.print("[green]Created[/green] .invar/mcp-setup.md (setup guide)")
+
+    return Success(configured)
+
+
+_MCP_SETUP_TEMPLATE = """\
+# Invar MCP Server Setup
+
+This project includes an MCP server that provides Invar tools to AI agents.
+
+## Available Tools
+
+| Tool | Replaces | Purpose |
+|------|----------|---------|
+| `invar_guard` | `pytest`, `crosshair` | Smart Guard verification |
+| `invar_sig` | `Read` entire file | Show contracts and signatures |
+| `invar_map` | `Grep` for functions | Symbol map with reference counts |
+
+## Configuration
+
+`invar init` automatically creates `.mcp.json` at project root with the correct Python path.
+
+### Claude Code
+
+The `.mcp.json` file is the standard MCP configuration for Claude Code.
+`invar init` creates/updates this file automatically.
+
+Manual setup (use your project's Python path):
+
+```json
+{
+  "mcpServers": {
+    "invar": {
+      "command": "/path/to/your/.venv/bin/python",
+      "args": ["-m", "invar.mcp"]
+    }
+  }
+}
+```
+
+Find your Python path: `python -c "import sys; print(sys.executable)"`
+
+## Installation
+
+Ensure the `mcp` package is installed:
+
+```bash
+pip install python-invar[mcp]
+```
+
+## Testing
+
+Run the MCP server directly:
+
+```bash
+python -m invar.mcp
+```
+
+The server communicates via stdio and should be managed by your AI agent.
+"""
+
+
 def install_hooks(path: Path, console) -> Result[bool, str]:
     """Install pre-commit hooks configuration and activate them."""
     import subprocess
